"use strict";

require("core-js/modules/es.regexp.flags.js");
require("core-js/modules/es.typed-array.set.js");
/*
 * Copyright OpenSearch Contributors
 * SPDX-License-Identifier: Apache-2.0
 */

require('babel-polyfill');
//# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJuYW1lcyI6WyJyZXF1aXJlIl0sInNvdXJjZXMiOlsic2V0dXBUZXN0cy50cyJdLCJzb3VyY2VzQ29udGVudCI6WyIvKlxuICogQ29weXJpZ2h0IE9wZW5TZWFyY2ggQ29udHJpYnV0b3JzXG4gKiBTUERYLUxpY2Vuc2UtSWRlbnRpZmllcjogQXBhY2hlLTIuMFxuICovXG5cbnJlcXVpcmUoJ2JhYmVsLXBvbHlmaWxsJyk7XG5yZXF1aXJlKCdjb3JlLWpzL3N0YWJsZScpOyAiXSwibWFwcGluZ3MiOiI7Ozs7QUFBQTtBQUNBO0FBQ0E7QUFDQTs7QUFFQUEsT0FBTyxDQUFDLGdCQUFnQixDQUFDIn0=